summaryrefslogtreecommitdiffstats
path: root/generic/tclGet.c
diff options
context:
space:
mode:
Diffstat (limited to 'generic/tclGet.c')
-rw-r--r--generic/tclGet.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/generic/tclGet.c b/generic/tclGet.c
index a60d3a6..9670450 100644
--- a/generic/tclGet.c
+++ b/generic/tclGet.c
@@ -110,7 +110,7 @@ Tcl_GetDouble(
* string.
*
* Results:
* The return value is normally TCL_OK; in this case *boolPtr will be set
* to the 0/1 value equivalent to src. If src is improperly formed then
* TCL_ERROR is returned and an error message will be left in the
* interp's result.
@@ -128,14 +128,14 @@ Tcl_GetBool(
const char *src, /* String containing one of the boolean values
* 1, 0, true, false, yes, no, on, off. */
int flags,
- char *boolPtr) /* Place to store converted result, which will
+ char *charPtr) /* Place to store converted result, which will
* be 0 or 1. */
{
Tcl_Obj obj;
int code;
if ((src == NULL) || (*src == '\0')) {
- return (Tcl_GetBoolFromObj)(interp, NULL, flags, boolPtr);
+ return (Tcl_GetBoolFromObj)(interp, NULL, flags, charPtr);
}
obj.refCount = 1;
obj.bytes = (char *) src;
@@ -147,7 +147,7 @@ Tcl_GetBool(
Tcl_Panic("invalid sharing of Tcl_Obj on C stack");
}
if (code == TCL_OK) {
- (Tcl_GetBoolFromObj)(NULL, &obj, flags, boolPtr);
+ (Tcl_GetBoolFromObj)(NULL, &obj, flags, charPtr);
}
return code;
}
@@ -110,7 +110,7 @@ Tcl_GetDouble(
*
* Results:
- * The return value is normally TCL_OK; in this case *boolPtr will be set
+ * The return value is normally TCL_OK; in this case *charPtr will be set
* to the 0/1 value equivalent to src. If src is improperly formed then
* TCL_ERROR is returned and an error message will be left in the